@@ -1,7 +1,7 @@
 package Perinci::Access::Schemeless;
 
-our $DATE = '2014-12-31'; # DATE
-our $VERSION = '0.79'; # VERSION
+our $DATE = '2015-03-06'; # DATE
+our $VERSION = '0.80'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,10 +11,11 @@ use Log::Any '$log';
 
 use parent qw(Perinci::Access::Base);
 
+use List::Util qw(first);
 use Perinci::Object;
 use Perinci::Sub::Normalize qw(normalize_function_metadata);
 use Perinci::Sub::Util qw(err);
-use Scalar::Util qw(blessed reftype);
+use Scalar::Util qw(blessed);
 use Module::Path::More qw(module_path);
 use Package::MoreUtil qw(package_exists);
 use Tie::Cache;
@@ -412,13 +413,10 @@ sub get_code {
     {
         # we don't need to wrap
         if (!$self->{wrap} ||
-                # .log is old name, we'll support it for some time
-                ($meta->{"x.perinci.sub.wrapper.log"} &&
-                     $meta->{"x.perinci.sub.wrapper.log"}[-1]{embed})
-                    ||
-                        ($meta->{"x.perinci.sub.wrapper.logs"} &&
-                             $meta->{"x.perinci.sub.wrapper.logs"}[-1]{embed})
-                    ) {
+                $meta->{"x.perinci.sub.wrapper.logs"} &&
+                    (first {$_->{validate}}
+                         @{ $meta->{"x.perinci.sub.wrapper.logs"} })
+            ) {
             $code = \&{$name};
             last GET_CODE;
         }
@@ -820,7 +818,7 @@ sub _pre_tx_action {
         unless $self->{use_tx};
 
     # instantiate custom tx manager, per request if necessary
-    if ((reftype($self->{custom_tx_manager}) // '') eq 'CODE') {
+    if (ref($self->{custom_tx_manager}) eq 'CODE') {
         eval {
             $self->{_tx_manager} = $self->{custom_tx_manager}->($self);
             die $self->{_tx_manager} unless blessed($self->{_tx_manager});
@@ -1022,7 +1020,7 @@ Perinci::Access::Schemeless - Base class for Perinci::Access::Perl
 
 =head1 VERSION
 
-This document describes version 0.79 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-12-31.
+This document describes version 0.80 of Perinci::Access::Schemeless (from Perl distribution Perinci-Access-Perl), released on 2015-03-06.
 
 =head1 DESCRIPTION
 
@@ -1245,7 +1243,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access-Perl>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Access-Perl>.
 
 =head1 BUGS
 
@@ -1261,7 +1259,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
